@@ -9,10 +9,10 @@ import traceback
 
 from pds_github_util.issues.utils import get_labels, is_theme
 from pds_github_util.zenhub.zenhub import Zenhub
-from pds_github_util.utils import GithubConnection
+from pds_github_util.utils import GithubConnection, addStandardArguments
 
 from pkg_resources import resource_string
-from pystache import Renderer
+from jinja2 import Template
 from yaml import FullLoader, load
 
 # PDS Github Org
@@ -59,6 +59,7 @@ def main():
 
     parser = argparse.ArgumentParser(formatter_class=argparse.RawDescriptionHelpFormatter,
         description=__doc__)
+    addStandardArguments(parser)
     parser.add_argument('--github_token',
                         help='github API token')
     parser.add_argument('--zenhub_token',
@@ -181,7 +182,7 @@ def main():
 
         with open(output_fname, 'w') as f_out:
 
-            pystache_dict = {
+            template_kargs = {
                 'output': output_fname,
                 'build_number': args.build_number,
                 'scr_date': key_dates['scr_date'],
@@ -196,9 +197,8 @@ def main():
                 'pds4_changes': ddwg_plans,
                 'planned_changes': plan_output
             }
-            renderer = Renderer()
-            template = resource_string(__name__,  'plan.template.rst')
-            rst_str = renderer.render(template, pystache_dict)
+            template = Template(resource_string(__name__,  'plan.template.rst').decode("utf-8"))
+            rst_str = template.render(template_kargs)
             f_out.write(rst_str)
 
             # else:
